@@ -5,13 +5,7 @@ from typing import Dict, List, Optional, Union
 
 from .utils import load_yaml
 
-DEPLOYMENT_ATTRIBUTES = [
-    "tags",
-    "image-tag",
-    "containers",
-    "environment",
-    "cluster",
-]
+DEPLOYMENT_ATTRIBUTES = ["tags", "image-tag", "containers", "environment", "cluster", "bump"]
 
 
 class App:
